@@ -1,4 +1,26 @@
 #!/usr/bin/python
+
+### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
+#
+#    Docker_is.py - python FullAuto Instruction Set using FullAuto API.
+#    Copyright © 2016  Brian M. Kelly
+#
+#    This program is free software: you can redistribute it and/or
+#    modify it under the terms of the GNU Affero General Public License
+#    as published by the Free Software Foundation, either version 3 of
+#    the License, or any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but **WITHOUT ANY WARRANTY**; without even the implied warranty
+#    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+#    GNU Affero General Public License for more details.
+#
+#    You should have received a copy of the GNU Affero General Public
+#    License along with this program.  If not, see:
+#    <http://www.gnu.org/licenses/agpl.html>.
+#
+#######################################################################
+
 from urllib import urlencode
 import httplib2
 import argparse
@@ -183,7 +205,10 @@ dockergid=''
 for inst in result['SecurityGroups']:
    print inst
    dockergid = inst['GroupId']
-   cidr      = inst['IpPermissions'][0]['IpRanges'][0]['CidrIp']
+   try:
+      cidr      = inst['IpPermissions'][0]['IpRanges'][0]['CidrIp']
+   except IndexError:
+      cidr      = ''
    if gid == inst['GroupId']:
       break
 new_sg   = 'aws ec2 create-security-group --group-name ' + \
