@@ -435,6 +435,7 @@ our $aws_configure=sub {
 
 my $configure_aws2=sub {
 
+   package configure_aws2;
    my $banner=<<'END';
 
      ___              _            _                      _  __
@@ -464,7 +465,7 @@ END
       Name => 'configure_aws2',
       Input  => 1,
       Banner => $banner,
-      Result => $aws_configure,
+      Result => $Net::FullAuto::Cloud::fa_amazon::aws_configure,
 
    );
    return \%configure_aws2;
@@ -928,6 +929,7 @@ END
 
       my $keyfilename="]I[{'ask_for_keyfile',1}";
       $keyfilename=~s/^.*\/(.*)(?:[.]pem)*$/$1/;
+      $keyfilename=~s/[.]pem$/$1/;
       my $pem_file=$keyfilename.'.pem';
       my $ppk_file=$keyfilename.'.ppk';
       my $upload_banner=<<'END';
@@ -1112,17 +1114,18 @@ sub new_user_amazon {
    } else {
       $identity_file=$pem_file=assist_user_to_upload_pemfile();
    }
+   my $homedir='.';
+   my $username=&Net::FullAuto::FA_Core::username();
+   if (can_load(modules => { "File::HomeDir" => 0 })) {
+      $homedir=File::HomeDir->my_home;
+   } elsif (-r "/home/$username") {
+      $homedir="/home/$username";
+   }
    if (exists $ENV{SUDO_USER} &&
          (-e "/home/$ENV{SUDO_USER}/credentials.csv")) {
       $credentials_csv_path="/home/$ENV{SUDO_USER}";
-   } else {
-      my $homedir='.';
-      my $username=&Net::FullAuto::FA_Core::username();
-      if (can_load(modules => { "File::HomeDir" => 0 })) {
-         $homedir=File::HomeDir->my_home;
-      } elsif (-r "/home/$username") {
-         $homedir="/home/$username";
-      }
+   #} elsif (-e "$homedir/.aws/credentials") {
+   } elsif (-e "$homedir/.aws/credentials") {
       open(RD,"$homedir/.aws/credentials");
       while (my $line=<RD>) {
          if ($line=~/^\s*aws_access_key_id\s*=\s*(\S+)/) {
